<?php
	declare(strict_types=1);
	/** @var FreshRSS_View $this */
	$this->partial('aside_configure');
?>
<main class="post">
	<h1><?= _t('admin.update') ?></h1>

	<?php
		// @phpstan-ignore function.notFound
		ask_info_update();
	?>
</main>
