<?php
declare(strict_types=1);
/** @var FreshRSS_View $this */
header('Content-Type: application/json; charset=UTF-8');

FreshRSS::loadStylesAndScripts();
echo json_encode([
		'tags' => $this->tagsForEntries,
	]);
